@@ -59,6 +59,7 @@ code from qwriter:
 #endif
 
 
+QHash <QString, QString> global_palette;
 QSettings *settings;
 QMenu *current_files_menu;
 
@@ -282,7 +283,7 @@ void CDocument::create_new()
 
   textEdit->doc = this;
 
-  textEdit->currentLineColor =  QColor (hash_get_val (holder->palette, 
+  textEdit->currentLineColor =  QColor (hash_get_val (global_palette, 
                                              "cur_line_color", 
                                              "#EEF6FF")).darker (settings->value ("darker_val", 100).toInt()).name();
 
@@ -518,8 +519,17 @@ QString CDocument::get_filename_at_cursor()
 }
 
 
+CSyntaxHighlighter::CSyntaxHighlighter (QTextDocument *parent, CDocument *doc, const QString &fname): QSyntaxHighlighter (parent) 
+{
+  qDebug() << "CSyntaxHighlighter::CSyntaxHighlighter";
+  document = doc; 
+  //casecare = true; 
+  //wrap = true;
+}
+
+
 CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDocument *doc, const QString &fname):
-                                        CSyntaxHighlighter (parent)
+                                                      CSyntaxHighlighter (parent, doc, fname)
 {
   document = doc;
   casecare = true;
@@ -531,12 +541,16 @@ CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDo
 #if QT_VERSION >= 0x050000
 
 CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTextDocument *parent, CDocument *doc, const QString &fname):
-                                        CSyntaxHighlighter (parent)
+                                                                            CSyntaxHighlighter (parent, doc, fname)
 {
+  qDebug() << "CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression";
+
   document = doc;
-  casecare = true;
-  wrap = true;
+  //casecare = true;
+  //wrap = true;
   load_from_xml (fname);
+  
+  qDebug() << "555 wrap: " << wrap;
 }
 
 #endif
@@ -577,15 +591,15 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
   else
      highlighter = new CSyntaxHighlighterQRegularExpression (textEdit->document(), this, fname);
   
-  
 #else
   
   highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
   
 #endif  
+
+  qDebug() << "highlighter->wrap: " << highlighter->wrap;
+
   
-  //highlighter->load_from_xml (fname);
-      
   if (textEdit->use_hl_wrap)
      {
       if (highlighter->wrap)
@@ -594,7 +608,7 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
           textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
      }
   
- // qDebug() << "hl file is: " << fname;
+  qDebug() << "textEdit->use_hl_wrap: " << textEdit->use_hl_wrap;
 }
 
 
@@ -608,30 +622,43 @@ void CDocument::goto_pos (int pos)
 
 void document_holder::apply_settings_single (CDocument *d)
 {
-  QFont f;
+  //QFont f;
 
   int darker_val = settings->value ("darker_val", 100).toInt();
 
-  
+/*  
   f.fromString (settings->value ("editor_font_name", "Monospace").toString());
   f.setPointSize (settings->value ("editor_font_size", "12").toInt());
   d->textEdit->setFont (f);
   d->textEdit->lineNumberArea->setFont (f);
+*/
 
+  
   d->textEdit->setCenterOnScroll (settings->value ("center_on_scroll", true).toBool());
   
   d->textEdit->use_hl_wrap = settings->value ("use_hl_wrap", true).toBool();
   
+  d->textEdit->wrap = settings->value ("word_wrap", true).toBool();
+    
+  if (! d->textEdit->use_hl_wrap)
+     {
+      if (d->textEdit->wrap)
+         d->textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
+      else
+          d->textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
+     }
+  
   if (settings->value ("right_to_left", false).toBool())
      d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignRight));
   else
      d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignLeft));
     
+    /*
   if (settings->value ("word_wrap", "2").toInt() == 2)
      d->textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
   else
       d->textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
-
+*/
   d->textEdit->tab_sp_width = settings->value ("tab_sp_width", 8).toInt();
   d->textEdit->spaces_instead_of_tabs = settings->value ("spaces_instead_of_tabs", true).toBool();
 
@@ -647,36 +674,36 @@ void document_holder::apply_settings_single (CDocument *d)
   d->textEdit->highlightCurrentLine = settings->value ("additional_hl", false).toBool();
   d->textEdit->hl_brackets = settings->value ("hl_brackets", false).toBool();
 
-  d->textEdit->currentLineColor = QColor (hash_get_val (palette, "cur_line_color", "#EEF6FF")).darker (darker_val);
-  d->textEdit->brackets_color = QColor (hash_get_val (palette, "brackets", "yellow")).darker (darker_val);
+  d->textEdit->currentLineColor = QColor (hash_get_val (global_palette, "cur_line_color", "#EEF6FF")).darker (darker_val);
+  d->textEdit->brackets_color = QColor (hash_get_val (global_palette, "brackets", "yellow")).darker (darker_val);
   
   d->cursor_xy_visible = settings->value ("cursor_xy_visible", "2").toBool();
   d->textEdit->auto_indent = settings->value ("auto_indent", false).toBool();
 
-  QString text_color = hash_get_val (palette, "text", "black");
+  QString text_color = hash_get_val (global_palette, "text", "black");
   QString t_text_color = QColor (text_color).darker(darker_val).name(); 
     
   d->textEdit->text_color = QColor (t_text_color);
 
-  QString back_color = hash_get_val (palette, "background", "white");
-  QString sel_back_color = hash_get_val (palette, "sel-background", "black");
-  QString sel_text_color = hash_get_val (palette, "sel-text", "white");
+  QString back_color = hash_get_val (global_palette, "background", "white");
+  //QString sel_back_color = hash_get_val (global_palette, "sel-background", "black");
+  //QString sel_text_color = hash_get_val (global_palette, "sel-text", "white");
 
-  d->textEdit->margin_color = QColor (hash_get_val (palette, "margin_color", text_color)).darker(darker_val);
-  d->textEdit->linenums_bg = QColor (hash_get_val (palette, "linenums_bg", back_color)).darker(darker_val);
+  d->textEdit->margin_color = QColor (hash_get_val (global_palette, "margin_color", text_color)).darker(darker_val);
+  d->textEdit->linenums_bg = QColor (hash_get_val (global_palette, "linenums_bg", back_color)).darker(darker_val);
   
-  QString t_back_color = QColor (back_color).darker(darker_val).name(); 
-  QString t_sel_text_color = QColor (sel_text_color).darker(darker_val).name(); 
-  QString t_sel_back_color = QColor (sel_back_color).darker(darker_val).name(); 
+  //QString t_back_color = QColor (back_color).darker(darker_val).name(); 
+  //QString t_sel_text_color = QColor (sel_text_color).darker(darker_val).name(); 
+  //QString t_sel_back_color = QColor (sel_back_color).darker(darker_val).name(); 
     
-  
+  /*
   QString sheet = QString ("QPlainTextEdit { color: %1 ; background-color: %2 ; selection-color: %3; selection-background-color: %4;}").arg (
                            t_text_color).arg (
                            t_back_color).arg (
                            t_sel_text_color).arg (
                            t_sel_back_color);
                            
-  d->textEdit->setStyleSheet (sheet);
+  d->textEdit->setStyleSheet (sheet);*/
   d->textEdit->repaint();
   d->set_hl();
 }
@@ -866,7 +893,14 @@ void CTEAEdit::paintEvent (QPaintEvent *event)
          }
      }
 
+  /*
+      QStyleOption opt;
+    opt.init(this);
+    QPainter p(this);
+    style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+*/
   QPlainTextEdit::paintEvent (event);
+
 }
 
 
@@ -882,7 +916,7 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
   highlightCurrentLine = false;
   setup_brace_width();
   
-  lineNumberArea = new LineNumberArea (this);
+  lineNumberArea = new CLineNumberArea (this);
   connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth(int)));
   connect(this, SIGNAL(updateRequest(const QRect &, int)), this, SLOT(updateLineNumberArea(const QRect &, int)));
   updateLineNumberAreaWidth (0);
@@ -892,7 +926,8 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
   draw_margin = false;
   hl_brackets = false;
   auto_indent = false;
-  use_hl_wrap = true;
+  use_hl_wrap = false;
+  wrap = true;
   tab_sp_width = 8;
   spaces_instead_of_tabs = true;
   
@@ -969,9 +1004,13 @@ QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &col
 
 #if QT_VERSION >= 0x050000
 
-
 void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 {
+ qDebug() << "CSyntaxHighlighterQRegularExpression::load_from_xml ";
+
+  wrap = true;
+  casecare = true;
+
   exts = "default";
   langs = "default";
   
@@ -1019,12 +1058,13 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                         
                      if (! casecare) 
                        pattern_opts = pattern_opts | QRegularExpression::CaseInsensitiveOption;                    
-                     
                      }
 
                  if (attr_type == "keywords")
                     {
-                     QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+//                     QString color = hash_get_val (document->holder->global_palette, xml.attributes().value ("color").toString(), "darkBlue");
+                     QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
+
                      QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
                      QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
@@ -1046,7 +1086,7 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                  else
                     if (attr_type == "item")
                        {
-                        QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                        QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
                         QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
                         HighlightingRule rule;
@@ -1061,7 +1101,7 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                     else
                         if (attr_type == "mcomment-start")
                            {
-                            QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "gray");
+                            QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "gray");
                             QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("color").toString(), color, darker_val);
 
                             multiLineCommentFormat = fmt;
@@ -1195,7 +1235,6 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                      if (! s_wrap.isNull() || ! s_wrap.isEmpty())
                         if (s_wrap == "0" || s_wrap == "false")
                            wrap = false;
-                        
 
                      QString s_casecare = xml.attributes().value ("casecare").toString();
                      if (! s_casecare.isNull() || ! s_casecare.isEmpty())
@@ -1208,7 +1247,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
 
                  if (attr_type == "keywords")
                     {
-                     QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                     QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
                      QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
                      QStringList keywordPatterns = xml.readElementText().trimmed().split(";");
@@ -1226,7 +1265,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                  else
                     if (attr_type == "item")
                        {
-                        QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "darkBlue");
+                        QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
                         QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
                         HighlightingRule rule;
@@ -1237,7 +1276,7 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
                     else
                         if (attr_type == "mcomment-start")
                            {
-                            QString color = hash_get_val (document->holder->palette, xml.attributes().value ("color").toString(), "gray");
+                            QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "gray");
                             QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("color").toString(), color, darker_val);
 
                             multiLineCommentFormat = fmt;
@@ -1354,7 +1393,7 @@ void document_holder::load_from_session (const QString &fileName)
   fname_current_session = fileName;
 }
 
-
+/*
 QHash <QString, QString> document_holder::load_eclipse_theme_xml (const QString &fname)
 {
   QHash <QString, QString> result;
@@ -1512,21 +1551,21 @@ QHash <QString, QString> document_holder::load_eclipse_theme_xml (const QString
    
    return result; 
 }
-
-
-void document_holder::load_palette (const QString &fileName)
+*/
+/*
+void document_holder::load_global_palette (const QString &fileName)
 {
   if (! file_exists (fileName))
       return;
 
-  palette.clear();
+  global_palette.clear();
   
   if (file_get_ext (fileName) == "xml")
-     palette = load_eclipse_theme_xml (fileName);
+     global_palette = load_eclipse_theme_xml (fileName);
   else
-      palette = hash_load_keyval (fileName);
+      global_palette = hash_load_keyval (fileName);
 }
-
+*/
 
 QString CDocument::get_selected_text() const
 {
