@@ -236,10 +236,8 @@ void CFMan::header_view_sortIndicatorChanged (int logicalIndex, Qt::SortOrder or
   sort_order = order;
   sort_mode = logicalIndex;
   
-  
   settings->setValue ("fman_sort_mode", sort_mode);
   settings->setValue ("fman_sort_order", sort_order);
-
   
   refresh();  
 }
@@ -558,8 +556,16 @@ void CFMan::drawRow (QPainter *painter, const QStyleOptionViewItem &option, cons
       o.rect = option.rect.adjusted(1,1,-1,-1);
       o.state |= QStyle::State_KeyboardFocusChange;
       o.state |= QStyle::State_Item;
+      
+      //o.backgroundColor = palette().color(QPalette::Background);
+      
+      //o.backgroundColor = QColor ("red");
 
       QApplication::style()->drawPrimitive (QStyle::PE_FrameFocusRect, &o, painter);
+      
+      QRect r = option.rect.adjusted(1,1,-1,-1);
+      
+      painter->drawRect (r);
      }
  else
     QTreeView::drawRow (painter, option, index);
