@@ -42,13 +42,16 @@ public:
 
   CZipper zipper;
   
+  int sort_mode;
+  Qt::SortOrder sort_order;
+  
   QStandardItemModel *mymodel;
   QList <QFileInfo> list;
   
   QDir dir;
     
   CFMan (QWidget *parent = 0);
-//  ~CFMan();
+  //~CFMan();
 
   void add_entry (const QFileInfo &fi);
   void append_dot_entry (const QString &fname);
@@ -69,6 +72,9 @@ public slots:
   void dir_up();
   void cb_fman_currentChanged (const QModelIndex &current, const QModelIndex &previous);
 
+  void header_view_sortIndicatorChanged(int logicalIndex, Qt::SortOrder order);
+
+  
 signals:
 
  void file_activated (const QString &path);
