@@ -10,7 +10,6 @@ this code is Public Domain
 #include <QLabel>
 
 
-
 void create_menu_from_list (QObject *handler,
                             QMenu *menu,
                             const QStringList &list,
@@ -61,6 +60,30 @@ void create_menu_from_dir (QObject *handler,
          }
 }
 
+//uses dir name as menuitem, no recursion
+void create_menu_from_dir_dir (QObject *handler,
+                               QMenu *menu,
+                               const QString &dir,
+                               const char *method
+                               )
+{
+  menu->setTearOffEnabled (true);
+  QDir d (dir);
+  QFileInfoList lst_fi = d.entryInfoList (QDir::NoDotAndDotDot | QDir::Dirs,
+                                          QDir::IgnoreCase | QDir::LocaleAware | QDir::Name);
+
+  foreach (QFileInfo fi, lst_fi)
+         {
+          if (fi.isDir())
+             {
+              QAction *act = new QAction (fi.fileName(), menu->parentWidget());
+              act->setData (fi.filePath());
+              handler->connect (act, SIGNAL(triggered()), handler, method);
+              menu->addAction (act);
+             }
+         }
+}
+
 
 QImage image_scale_by (const QImage &source,
                        bool by_side,
