@@ -9,7 +9,6 @@
 #include <QBoxLayout>
 
 
-
 void create_menu_from_list (QObject *handler,
                             QMenu *menu,
                             const QStringList &list,
@@ -23,6 +22,13 @@ void create_menu_from_dir (QObject *handler,
                            const char *method
                            );
 
+void create_menu_from_dir_dir (QObject *handler,
+                               QMenu *menu,
+                               const QString &dir,
+                               const char *method
+                               );
+
+
 
 QImage image_scale_by (const QImage &source,
                        bool by_side,
@@ -43,6 +49,4 @@ QComboBox* new_combobox (QBoxLayout *layout,
                          const QString &def_value);
 
 
-
-
 #endif // GUI_UTILS_H
