@@ -1,3 +1,8 @@
+/*
+this code is Public Domain
+*/
+
+
 #include "img_viewer.h"
 #include "utils.h"
 
@@ -370,17 +375,16 @@ void CZORWindow::resizeEvent(QResizeEvent *event)
 
 void CZORWindow::load_image (const QString &fname)
 {
-  if  (! file_exists (fname))
+  if (! file_exists (fname))
      return;
 
+  qDebug() << "CZORWindow::load_image " << fname;
+  
   fname_image = fname;
  
-  //transform.reset();
- 
-  source_image.load (fname);
-  //transformed_image = source_image;
-
-  //QSize new_size = source_image.size();
+  if (! source_image.load (fname))
+     qDebug() << "cannot load " << fname;
+     
   
   bool orientation_portrait = false; 
   bool need_to_scale = false;
@@ -402,16 +406,17 @@ void CZORWindow::load_image (const QString &fname)
   resize (source_image.size());
     
   QString s_wnd_title (QFileInfo (fname_image).fileName());
-  s_wnd_title.append (tr (" scaled to"));
-  s_wnd_title.append (QString (" - %1x%2").arg (source_image.width()).arg(source_image.height()));
+  s_wnd_title.append (" ");
+  s_wnd_title.append (tr ("scaled to: "));
+  s_wnd_title.append (QString ("%1x%2").arg (source_image.width()).arg(source_image.height()));
   setWindowTitle (s_wnd_title);
 
+  update();
   raise();
   activateWindow();
 }
 
 
-
 void CZORWindow::keyPressEvent (QKeyEvent * event)
 {
   if (event->key() == Qt::Key_Escape)
