@@ -28,17 +28,21 @@
 #include <QString>
 
 
-class CLogMemo: public QObject
+
+class CLogMemo: public QPlainTextEdit
 {
   Q_OBJECT
 
 public:
 
-  QPlainTextEdit *memo;
-  CLogMemo (QPlainTextEdit *m);
+//  QPlainTextEdit *memo;
+  //CLogMemo (QPlainTextEdit *m);
 
-public slots:
+  CLogMemo ( QWidget * parent = 0);
 
+//public slots:
+
+  
   void log (const QString &text);
 };
 
