@@ -26,6 +26,9 @@
 
 #include "single_application.h"
 
+
+extern rvln *mainWindow; 
+
 int main (int argc, char *argv[])
 {
 // Q_INIT_RESOURCE (rlvn);
@@ -36,9 +39,12 @@ int main (int argc, char *argv[])
   CApplication app (argc, argv);
   qApp->setApplicationName ("TEA");
   
-  rvln mw;
+  //rvln mw;
 
-  mw.show();
+  //mw.show();
+  
+  mainWindow = new rvln();
+  mainWindow->show();
 
   return app.exec();
   
@@ -59,7 +65,8 @@ int main (int argc, char *argv[])
      }
   
   
-  rvln *mainWindow = new rvln();
+  //rvln *mainWindow = new rvln();
+  mainWindow = new rvln();
 
   QObject::connect(&app, SIGNAL(messageAvailable(QString)), mainWindow, SLOT(receiveMessage(QString)));
   
