@@ -42,6 +42,7 @@
 #include <QProgressBar>
 #include <QCheckBox>
 #include <QSpinBox>
+//#include <QToolButton>
 #include <QFontComboBox>
 #include <QSessionManager>
 #include <QApplication>
@@ -254,6 +255,10 @@ public:
   QComboBox *cmb_fif;
   
 
+  //QString stylesheet; 
+  QString fname_stylesheet; 
+
+
   QString man_search_value;
 
   QString markup_mode;
@@ -275,6 +280,7 @@ public:
   QString dir_templates;
   QString dir_sessions;
   QString dir_hls;
+  QString dir_themes;
 
 
 //#if QT_VERSION >= 0x050000
@@ -324,7 +330,8 @@ public:
 
   QSpinBox *spb_fuzzy_q;
 
-
+  //QToolButton *tb_current_list;
+  
   QLineEdit *ed_label_end;
   QLineEdit *ed_label_start;
 
@@ -370,6 +377,8 @@ main window callbacks
 
   void receiveMessage(const QString &msg);
   
+  void view_use_theme();
+
 
   void select_label();
   void update_labels_menu();
@@ -741,7 +750,7 @@ main window widgets
 
   QSplitter *mainSplitter;
   QTextBrowser *man;
-  QPlainTextEdit *log_memo;
+ // QPlainTextEdit *log_memo;
   QString charset;
 
   QTabWidget *main_tab_widget;
@@ -782,6 +791,9 @@ main window widgets
   QMenu *menu_fn_plugins;
 
 #endif  
+
+  QMenu *menu_view_themes;
+
   
   QMenu *menu_markup;
   QMenu *menu_functions;
@@ -898,6 +910,9 @@ prefs window widgets
                         );
 
 
+  void update_stylesheet (const QString &f);
+  
+
   void update_dyn_menus();
   void create_paths();
   
@@ -911,6 +926,8 @@ prefs window widgets
 
 #endif
 
+  void init_styles();
+
   void handle_args();
 
   void leaving_tune();
@@ -936,6 +953,10 @@ prefs window widgets
 
 #endif
   
+  void update_themes();
+
+
+  
   void update_hls (bool force = false);
 
   void update_tables();
@@ -968,6 +989,11 @@ prefs window widgets
 
   void run_unitaz (int mode);
  
+ QHash <QString, QString> load_eclipse_theme_xml (const QString &fname);
+
+  void load_palette (const QString &fileName);
+
+ 
   QTextDocument::FindFlags get_search_options();
 
   void fman_convert_images (bool by_side, int value);
