@@ -7,13 +7,19 @@
  * 
  */
 
-#ifndef Q_OS_OS2
 
 #ifndef SINGLE_APPLICATION_H
 #define SINGLE_APPLICATION_H
 
 #include <QApplication>
+
+
+#ifndef Q_OS_OS2
 #include <QSharedMemory>
+#endif
+
+
+
 #include <QLocalServer>
 
 class SingleApplication : public QApplication
@@ -34,11 +40,15 @@ signals:
 private:
         bool _isRunning;
         QString _uniqueKey;
+
+#ifndef Q_OS_OS2
+
         QSharedMemory sharedMemory;
+        
+#endif        
         QLocalServer *localServer;
 
         static const int timeout = 1000;
 };
 #endif // SINGLE_APPLICATION_H
 
-#endif //Q_OS_OS2
\ No newline at end of file
