@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2013 by Peter Semiletov                                          *
+ *   2007-2014 by Peter Semiletov                                          *
  *   tea@list.ru                                                           *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -210,12 +210,16 @@ QStringList CSpellchecker::get_suggestions_list (const QString &word)
 
 CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, const QString &user_path): ASpellchecker (lang, path, user_path)
 {
+  qDebug() << "CHunspellChecker::CHunspellChecker - start";
+
+
   initialized = false;
 
   dict_dir = path;
   user_dir = user_path; 
   lng = lang;
 
+
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   QString fname_aff = path + QDir::separator() + lng + ".aff";
@@ -234,9 +238,32 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
 
 #endif
 
+
+#if defined(Q_OS_WIN)
+
+  fname_aff = "\\\\?\\" + fname_aff;
+  fname_dict = "\\\\?\\" + fname_dict;
+  fname_userdict = "\\\\?\\" + fname_userdict;
+
+#endif
+
+
+
+//qDebug() << fname_aff;
+//qDebug() << fname_dict;
+//qDebug() << fname_userdict;
+
+
   speller = new Hunspell (fname_aff.toUtf8().data(), fname_dict.toUtf8().data());
   encoding = speller->get_dic_encoding();
 
+
+//    const char *c_aff = fname_aff.toLocal8Bit().constData();
+  //  const char *c_dict = fname_dict.toLocal8Bit().constData();
+
+//    speller = new Hunspell (c_aff, c_dict);
+
+  
   if (file_exists (fname_userdict))
      {
       speller->add_dic (fname_userdict.toUtf8().data());
@@ -251,6 +278,9 @@ CHunspellChecker::CHunspellChecker (const QString &lang, const QString &path, co
   //    initialized = true;
 //  else
   //    qDebug() << "Hunspell engine is not initilized with a proper dictionary file " << fname_dict;
+
+  qDebug() << "CHunspellChecker::CHunspellChecker - end";
+
 }
 
 
