@@ -10,7 +10,7 @@
 bool CTioPlainText::load (const QString &fname)
 {
 
- qDebug() << "EOL detection - start";
+ //qDebug() << "EOL detection - start";
 
   QFile feol_detector (fname);
 
@@ -32,6 +32,7 @@ bool CTioPlainText::load (const QString &fname)
       if (block.indexOf ('\r') != -1)
           eol = "\r";
 
+  /*
    if (eol == "\n")
      qDebug() << "LF";
    if (eol == "\r\n")
@@ -40,7 +41,7 @@ bool CTioPlainText::load (const QString &fname)
      qDebug() << "CR";
 
   qDebug() << "EOL detection - end";
-
+*/
   feol_detector.close();
 
   QFile file (fname);
