@@ -1,8 +1,14 @@
 #ifndef TIO_H
 #define TIO_H
 
-//#include <QtCore>
-#include <QtXml>
+
+#include <QObject>
+#include <QList>
+#include <QByteArray>
+#include <QString>
+#include <QStringList>
+
+//try http://qt-project.org/doc/qt-5.0/qtcore/qxmlstreamreader.html for qt5
 
 
 class CSignaturesList: public QObject
@@ -30,39 +36,6 @@ public:
 };
 
 
-class CXMLWalker: public QObject
-{
-  Q_OBJECT
-
-public:
-
-  QString data;
-  QDomDocument doc;
-
-  virtual void step (QDomNode node) = 0;
-};
-
-
-class CABWXMLWalker: public CXMLWalker
-{
-  Q_OBJECT
-
-public:
-
-  void step (QDomNode node);
-};
-
-
-class CSLAXMLWalker: public CXMLWalker
-{
-  Q_OBJECT
-
-public:
-
-  void step (QDomNode node);
-};
-
-
 class CTio: public QObject
 {
   Q_OBJECT
@@ -74,6 +47,8 @@ public:
   QString charset;
   QString error_string;
 
+  QString eol;
+
   QStringList extensions;
 
   virtual bool load (const QString &fname) = 0;
@@ -159,18 +134,6 @@ public:
 };
 
 
-
-class CTioSLA: public CTioReadOnly
-{
-  Q_OBJECT
-
-public:
-
-  CTioSLA();
-  bool load (const QString &fname);
-};
-
-
 class CTioRTF: public CTioReadOnly
 {
   Q_OBJECT
