@@ -312,7 +312,7 @@ bool CZipper::unzip (const QString &archpath, const QString &destdir)
   return true;
 }
 
-
+/*
 QString CZipper::unzip_info (const QString &archpath)
 {
   QuaZip zip (archpath, settings->value ("zip_charset_in", "UTF-8").toString().trimmed());
@@ -342,4 +342,34 @@ QString CZipper::unzip_info (const QString &archpath)
   zip.close();
   return result;
 }
+*/
+
+QStringList CZipper::unzip_list (const QString &archpath)
+{
+  QuaZip zip (archpath, settings->value ("zip_charset_in", "UTF-8").toString().trimmed());
+
+  if (! zip.open (QuaZip::mdUnzip))
+      {
+       qDebug() << "zip.open() error: " << zip.getZipError();
+       return QStringList();
+      }
+
+  QStringList result;
+
+  QuaZipFileInfo info;
+
+  for (bool more = zip.goToFirstFile(); more; more = zip.goToNextFile())
+      {
+       if (! zip.getCurrentFileInfo (&info))
+          {
+           qDebug() << "getCurrentFileInfo()" << zip.getZipError();
+           return QStringList();
+          }
+
+       result.prepend (info.name);
+      }
+
+  zip.close();
+  return result;
+}
 
